@@ -12,17 +12,13 @@
 #' @param total A boolean for returning the total number rather than the
 #' proportion of the country's population. The default value is TRUE
 #' @param plot A boolean for displaying a plot. The default value is TRUE
-#' @param language Language for plot components
 #' @importFrom rlang .data
 #' @return A dataframe with the proportion or total count of individuals
 #' @examples
 #' population_pyramid("15001", 2015, sex = TRUE, total = TRUE, plot = TRUE)
 #' @export
 population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
-                               total = TRUE, plot = FALSE, language = c(
-                                 "EN",
-                                 "ES"
-                               )) {
+                               total = TRUE, plot = FALSE) {
   stopifnot(
     "`year` must be an unique value" = (length(year) == 1),
     "`divipola_code` must be a character of a positive integer" = (
@@ -31,7 +27,6 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
     "`range` must be an integer value between 1 and 100" = is.numeric(range) &
       range %in% seq(1, 100)
   )
-  language <- match.arg(language)
   path <- system.file("extdata", "divipola_table.rda", package = "epiCo")
   load(path)
   divipola_table <- divipola_table
@@ -49,8 +44,8 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
     )
     pop_data_dpto <- dplyr::filter(
       population_projection_col_0,
-      ((population_projection_col_0$dp == divipola_code) &
-        (population_projection_col_0$ano == year))
+      .data$dp == divipola_code,
+      .data$ano == year
     )
 
     female_counts <- as.numeric(pop_data_dpto[104:204])
@@ -70,7 +65,8 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
     )
     pop_data_dpto <- dplyr::filter(
       population_projection_col_1,
-      ((.data$dp == divipola_code) & (.data$ano == year))
+      .data$dp == divipola_code,
+      .data$ano == year
     )
 
     female_counts <- as.numeric(pop_data_dpto[104:204])
@@ -81,10 +77,9 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
       .data$COD_DPTO == divipola_code
     ) %>%
       dplyr::slice(1) %>%
-      dplyr::pull(.data$NOM_DPTO)
-    name <- tolower(substr(name, 1, 1)) %>%
-      toupper() %>%
-      paste0(tolower(substr(name, 2, nchar(name))))
+      dplyr::pull(.data$NOM_DPTO) %>%
+      tolower() %>%
+      tools::toTitleCase()
   } else if (divipola_code %in% divipola_table$COD_MPIO) {
     path_2 <- system.file("extdata", "population_projection_col_2.rds",
       package = "epiCo"
@@ -98,7 +93,8 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
     )
     pop_data_mun <- dplyr::filter(
       population_projection_col_2,
-      ((.data$dpmp == divipola_code) & (.data$ano == year))
+      .data$dpmp == divipola_code,
+      .data$ano == year
     )
 
     female_counts <- as.numeric(pop_data_mun[89:174])
@@ -108,10 +104,9 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
       divipola_table,
       .data$COD_MPIO == divipola_code
     ) %>%
-      dplyr::pull(.data$NOM_MPIO)
-    name <- tolower(substr(name, 1, 1)) %>%
-      toupper() %>%
-      paste0(tolower(substr(name, 2, nchar(name))))
+      dplyr::pull(.data$NOM_MPIO) %>%
+      tolower() %>%
+      tools::toTitleCase()
   } else {
     stop("There is no location assigned to the consulted DIVIPOLA code")
   }
@@ -157,28 +152,16 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
 
   if (plot) {
     pop_pyramid_plot <- population_pyramid_plot(pop_pyramid,
-      language = language, sex = sex
+      sex = sex
     )
     if (total) {
-      if (language == "EN") {
-        pop_pyramid_plot <- pop_pyramid_plot +
-          ggplot2::ylab("Total population") +
-          ggplot2::ggtitle(paste(name, "population pyramid"))
-      } else {
-        pop_pyramid_plot <- pop_pyramid_plot +
-          ggplot2::ylab("Poblacion total") +
-          ggplot2::ggtitle(paste("Piramide poblacional", name))
-      }
+      pop_pyramid_plot <- pop_pyramid_plot +
+        ggplot2::ylab(tr_("Total population")) +
+        ggplot2::ggtitle(paste(name, tr_("population pyramid")))
     } else {
-      if (language == "EN") {
-        pop_pyramid_plot <- pop_pyramid_plot +
-          ggplot2::ylab("Proportion of population") +
-          ggplot2::ggtitle(paste(name, "population pyramid"))
-      } else {
-        pop_pyramid_plot <- pop_pyramid_plot +
-          ggplot2::ylab("Proporcion de la poblacion") +
-          ggplot2::ggtitle(paste("Piramide poblacional", name))
-      }
+      pop_pyramid_plot <- pop_pyramid_plot +
+        ggplot2::ylab(tr_("Proportion of population")) +
+        ggplot2::ggtitle(paste(name, tr_("population pyramid")))
     }
     print(pop_pyramid_plot)
     return(list(data = pop_pyramid, plot = pop_pyramid_plot))
@@ -196,12 +179,11 @@ population_pyramid <- function(divipola_code, year, sex = TRUE, range = 5,
 #' @param pop_pyramid A dataframe with the age counts
 #' @param sex A boolean to consult data disaggregated by sex. The default value
 #' is TRUE
-#' @param language Language for plot components
 #'
 #' @return the population pyramid plot
 #'
 #' @keywords internal
-population_pyramid_plot <- function(pop_pyramid, language, sex = TRUE) {
+population_pyramid_plot <- function(pop_pyramid, sex = TRUE) {
   if (sex) {
     female_total <- dplyr::filter(pop_pyramid, .data$sex == "F")$population
     male_total <- dplyr::filter(pop_pyramid, .data$sex == "M")$population
@@ -210,62 +192,46 @@ population_pyramid_plot <- function(pop_pyramid, language, sex = TRUE) {
     pop_pyramid_plot <- ggplot2::ggplot(
       pop_pyramid,
       ggplot2::aes(
-        x = .data$age,
-        y = .data$population,
+        x = .data$population,
+        y = .data$age,
         fill = .data$sex
       )
     ) +
-      ggplot2::geom_col(
-        data = dplyr::filter(pop_pyramid, .data$sex == "F")
-      ) +
-      ggplot2::geom_col(
-        data = dplyr::filter(pop_pyramid, .data$sex == "M")
-      ) +
-      ggplot2::scale_y_continuous(
+      ggplot2::geom_col(orientation = "y") +
+      ggplot2::scale_x_continuous(
+        name = tr_("Population"),
         breaks = scales::breaks_extended(n = 8),
         labels = function(x) {
           as.character(abs(as.numeric(x)))
         }
       ) +
-      ggplot2::coord_flip()
-    if (language == "EN") {
-      pop_pyramid_plot <- pop_pyramid_plot +
-        ggplot2::scale_x_continuous(
-          name = "Age",
-          breaks = unique(pop_pyramid$age),
-          labels = unique(pop_pyramid$age)
-        )
-    } else {
-      pop_pyramid_plot <- pop_pyramid_plot +
-        ggplot2::scale_x_continuous(
-          name = "Edad",
-          breaks = unique(pop_pyramid$age),
-          labels = unique(pop_pyramid$age)
-        )
-    }
-
+      ggplot2::scale_y_continuous(
+        name = tr_("Age"),
+        breaks = unique(pop_pyramid$age),
+        labels = unique(pop_pyramid$age)
+      )
     pop_pyramid$population <- c(female_total, male_total)
   } else {
     pop_pyramid_plot <- ggplot2::ggplot(
       pop_pyramid,
       ggplot2::aes(
-        x = .data$age,
-        y = .data$population
+        x = .data$population,
+        y = .data$age
       )
     ) +
-      ggplot2::geom_bar(stat = "identity") +
-      ggplot2::scale_y_continuous(
+      ggplot2::geom_bar(stat = "identity", orientation = "y") +
+      ggplot2::scale_x_continuous(
+        name = tr_("Population"),
         breaks = scales::breaks_extended(n = 8),
         labels = function(x) {
           as.character(abs(as.numeric(x)))
         }
       ) +
-      ggplot2::scale_x_continuous(
-        name = "Age",
+      ggplot2::scale_y_continuous(
+        name = tr_("Age"),
         breaks = pop_pyramid$age,
         labels = pop_pyramid$age
-      ) +
-      ggplot2::coord_flip()
+      )
   }
   return(pop_pyramid_plot)
 }
@@ -280,7 +246,6 @@ population_pyramid_plot <- function(pop_pyramid, language, sex = TRUE) {
 #' @param population_pyramid A dataframe with the count of individuals with the
 #' columns age, population and sex
 #' @param plot A boolean for displaying a plot. The default value is FALSE
-#' @param language Language for plot components
 #' @importFrom rlang .data
 #' @return A dataframe with the proportion or total count of individuals
 #' @examples
@@ -295,11 +260,11 @@ population_pyramid_plot <- function(pop_pyramid, language, sex = TRUE) {
 #'   plot = TRUE
 #' )
 #' @export
-age_risk <- function(age, population_pyramid, sex = NULL, plot = FALSE,
-                     language = c("EN", "ES")) {
-  stopifnot("`age` must be an integer numeric vector with values
-            between 0 and 100" = all(age %in% seq(0, 100)))
-  language <- match.arg(language)
+age_risk <- function(age, population_pyramid, sex = NULL, plot = FALSE) {
+  stopifnot(
+    "`age` must be a numeric vector with values greater than 0" =
+      ((all(age > 0)) & (is.numeric(age)))
+  )
   if (inherits(population_pyramid, what = "list")) {
     population_pyramid <- population_pyramid$data
   }
@@ -345,38 +310,19 @@ age_risk <- function(age, population_pyramid, sex = NULL, plot = FALSE,
   if (plot) {
     if (!is.null(sex)) {
       age_risk_plot <- population_pyramid_plot(age_risk,
-        language = language,
         sex = TRUE
-      )
-      if (language == "EN") {
+      ) +
         # nolint start
-        age_risk_plot <- age_risk_plot +
-          ggplot2::ylab("Cases / Population") +
-          ggplot2::ggtitle("Specific rate by age group")
+        ggplot2::ylab(tr_("Cases / Population")) +
         # nolint end
-      } else {
-        # nolint start
-        age_risk_plot <- age_risk_plot +
-          ggplot2::ylab("Casos / Poblacion") +
-          ggplot2::ggtitle("Tasa especifica por grupo de edad")
-        # nolint end
-      }
+        ggplot2::ggtitle(tr_("Specific rate by age group"))
     } else {
       age_risk_plot <- population_pyramid_plot(age_risk,
-        language = language,
         sex = FALSE
-      )
-      if (language == "EN") {
-        age_risk_plot <- age_risk_plot +
-          # nolint start
-          ggplot2::ylab("Cases / Population")
-        # nolint end
-      } else {
-        age_risk_plot <- age_risk_plot +
-          # nolint start
-          ggplot2::ylab("Casos / Poblacion")
-        # nolint end
-      }
+      ) +
+        # nolint start
+        ggplot2::ylab(tr_("Cases / Population"))
+      # nolint end
     }
     print(age_risk_plot)
     return(list(data = age_risk, plot = age_risk_plot))
@@ -421,93 +367,54 @@ get_age_risk_sex <- function(age, sex_vector, pyramid, sex) {
 #' ethnicities
 #' @param ethnic_codes A numeric vector with the codes of ethnicities to
 #' consult
-#' @param language "ES" for description in Spanish "EN" for English. The default
-#' value is EN
 #' @return A printed message with ethnicities descriptions
 #' @examples
 #' describe_ethnicity(round(runif(n = 150, min = 1, max = 4)))
 #' @export
-describe_ethnicity <- function(ethnic_codes, language = c("EN", "ES")) {
+describe_ethnicity <- function(ethnic_codes) {
   stopifnot(
     "`ethnic_codes` must be a numeric vector" =
       is.numeric(ethnic_codes)
   )
-  language <- match.arg(language)
   ethnic_codes <- as.data.frame(ethnic_codes)
-  #### ESPA<U+00D1>OL ####
-  indigena_es <- paste(
-    "Persona de ascendencia amerindia que comparten sentimientos de",
-    "identificacion con su pasado aborigen, manteniendo rasgos y valores",
-    "propios de su cultura tradicional, asi como formas de organizacion y",
-    "control social propios"
-  )
 
-  rom_es <- paste(
-    "Son comunidades que tienen una identidad etnica y cultural propia; se",
-    "caracterizan por una tradicion nomada, y tienen su propio idioma que es",
-    "el romanes"
-  )
-
-  raizal_es <- paste(
-    "Poblacion ubicada en el Archipielago de San Andres, Providencia y Santa",
-    "Catalina, con raices culturales afroanglo-antillanas, cuyos integrantes",
-    "tienen rasgos socioculturales y linguisticos claramente diferenciados del",
-    "resto de la poblacion afrocolombiana"
-  )
-
-  palenquero_es <- paste(
-    "Poblacion ubicada en el municipio de San Basilio de Palenque,",
-    "departamento de Bolivar, donde se habla el palenquero, lenguaje criollo"
-  )
-
-  afro_es <- paste(
-    "Persona de ascendencia afrocolombiana que poseen una cultura propia, y",
-    "tienen sus propias tradiciones y costumbre dentro de la relacion",
-    "campo-poblado"
-  )
-
-  #### ENGLISH ####
   indigena_en <- paste(
-    "A person of Amerindian descent who shares feelings of identification with",
-    "their aboriginal past, maintaining traits and values of their traditional",
-    "culture, as well as their own forms of organization and social control"
+    tr_("A person of Amerindian descent who shares feelings of identification"),
+    tr_("with their aboriginal past, maintaining traits and values of their"),
+    tr_("traditional culture, as well as their own forms of organization and"),
+    tr_("social control")
   )
 
   rom_en <- paste(
-    "They are communities that have their own ethnic and cultural identity;",
-    "They are characterized by a nomadic tradition, and have their own",
-    "language, which is Romanesque"
+    tr_("They are communities that have their own ethnic and cultural"),
+    tr_("identity; They are characterized by a nomadic tradition, and have"),
+    tr_("their own language, which is Romanesque")
   )
 
   raizal_en <- paste(
-    "Population located in the Archipelago of San Andres, Providencia and",
-    "Santa Catalina, with Afro-Anglo-Antillean cultural roots, whose members",
-    "have clearly differentiated sociocultural and linguistic traits from the",
-    "rest of the Afro-Colombian population"
+    tr_("Population located in the Archipelago of San Andres, Providencia and"),
+    tr_("Santa Catalina, with Afro-Anglo-Antillean cultural roots, whose"),
+    tr_("members have clearly differentiated sociocultural and linguistic"),
+    tr_("traits from the rest of the Afro-Colombian population")
   )
 
   palenquero_en <- paste(
-    "Population located in the municipality of San Basilio de Palenque,",
-    "department of Bolivar, where palenquero is spoken, a Creole language"
+    tr_("Population located in the municipality of San Basilio de Palenque,"),
+    tr_("department of Bolivar, where palenquero is spoken, a Creole language")
   )
 
   afro_en <- paste(
-    "Person of Afro-Colombian descent who have their own culture, and have",
-    "their own traditions and customs within the rural-populatedrelationship"
+    tr_("Person of Afro-Colombian descent who have their own culture, and"),
+    tr_("have their own traditions and customs within the rural-populated"),
+    tr_("relationship")
   )
 
-  descriptions_es <- c(indigena_es, rom_es, raizal_es, palenquero_es, afro_es)
   descriptions_en <- c(indigena_en, rom_en, raizal_en, palenquero_en, afro_en)
 
   codes <- sort(unique(ethnic_codes$ethnic_codes))
   descrip_en <- descriptions_en[codes]
-  descrip_es <- descriptions_es[codes]
 
-  if (language == "EN") {
-    return(data.frame(code = codes, description = descrip_en))
-  } else {
-    return(data.frame(codigo = codes, descripcion = descrip_es))
-  }
+  return(data.frame(code = codes, description = descrip_en))
 }
 
 #' Get ISCO-88 occupation labels from codes
@@ -819,7 +726,7 @@ occupation_plot <- function(occupation_data, sex = FALSE, q = 0.9) {
     treemapify::geom_treemap() +
     ggplot2::scale_fill_manual(
       name = "Major Group",
-      values = RColorBrewer::brewer.pal(n = 12, name = "Set3")
+      values = grDevices::palette.colors(n = 12, palette = "Set3")
     ) +
     treemapify::geom_treemap_text(
       colour = "grey16", place = "centre",
@@ -908,7 +815,7 @@ occupation_plot_circular <- function(occupation_data, q = 0.9) {
     ggraph::geom_node_circle(ggplot2::aes(fill = .data$sub_major)) +
     ggplot2::scale_fill_manual(
       name = "Major Group",
-      values = RColorBrewer::brewer.pal(n = 12, name = "Set3"),
+      values = grDevices::palette.colors(n = 12, palette = "Set3"),
       labels = circle_vertices$sub_major
     ) +
     ggraph::geom_node_text(ggplot2::aes(label = .data$unit)) +
